@@ -1,5 +1,5 @@
 import click
-from lib.file import identify as identify_plus
+from gex.lib.file import identify as identify_plus
 
 @click.command()
 @click.option('--in', 'in_file', help = 'path to input file', required=True)
